##  Vendor-Provided Lifecycle Information for IT Components
SAP LeanIX Technology Risk and Compliance offers vendor-provided lifecycle and end-of-support information for IT component fact sheets from the SAP LeanIX reference catalog.
Vendor-provided lifecycle information is updated in dedicated vendor lifecycle fields. This ensures that you can maintain distinct internal lifecycles when operational dependencies or your organizational IT strategy require a different timeline. For more details, see [Vendor Lifecycle Dates](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD#loio275adf737a44101482dccd5ff2ab307e__lifecycle_states_of_it_components).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio99ee0555192d4c6889577f728c3e4ff6_LowRes.png)
Internal and Vendor Lifecycle Fields
For some products or product versions, vendors may offer extended support after the standard support period. If your organization has an individual extended support agreement with a vendor, you can capture this information in the End of Extended Support Agreement field, providing relevant context in a comment.
Both vendor and internal lifecycle information are considered and aggregated to assess the obsolescence risk statuses of applications. This enables effective end-of-life asset management and supports proactive decisions on upgrades, transformations, or replacements for obsolescence risk management. To learn more about obsolescence risk aggregation and statuses, see [Technology Obsolescence Risk Statuses and Views in Reports](https://help.sap.com/docs/leanix/ea/technology-obsolescence-risk-statuses-and-views-in-reports?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how risk statuses are determined for IT components and applications and understand reporting views, such as Missing Data Percentage, Mitigated Risk Percentage, and Unaddressed Risk Percentage.").
